
/*
 * Web Polygraph                        http://www.web-polygraph.org/
 * ------------------------------------------------------------------
 *
 *  Web Polygraph is copyrighted (C) 1998-2000 by The Regents of the
 *  University of California. See the COPYRIGHT file for details.
 */

#include "base/polygraph.h"

#include <fstream.h>

#include "xml/XmlAttr.h"
#include "loganalyzers/LevelStex.h"
#include "loganalyzers/ReportBlob.h"
#include "loganalyzers/BlobDb.h"
#include "loganalyzers/RepOpts.h"
#include "loganalyzers/PhaseInfo.h"
#include "loganalyzers/PhaseTrace.h"
#include "loganalyzers/LevelTraceFig.h"


LevelTraceFig::LevelTraceFig(): theStex1(0), theStex2(0), thePhase(0), theTrace(0) {
}

void LevelTraceFig::stats(const Stex *aStex1, const Stex *aStex2, const PhaseInfo *aPhase) {
	theStex1 = aStex1;
	theStex2 = aStex2;
	thePhase = aPhase;
	theTrace = &thePhase->trace();
	Assert(theTrace);
}

void LevelTraceFig::setCtrlOptions() {
	ReportTraceFigure::setCtrlOptions();
	*theCtrlFile << "set size 1.0,0.5" << endl;
	*theCtrlFile << "set xlabel 'minutes'" << endl;
	*theCtrlFile << "set ylabel 'level, #'" << endl;
}

int LevelTraceFig::createCtrlFile() {
	if (ReportTraceFigure::createCtrlFile() < 0)
		return -1;

	*theCtrlFile << "plot '-' title '" << theStex1->name() 
		<< "' with lines";
	if (theStex2) {
		*theCtrlFile << ", \\" << endl
			<< "\t '-' title '" << theStex2->name()
			<< "' with lines" << endl;
	} else {
		*theCtrlFile << endl;
	}

	int pointCount = 0;
	pointCount += dumpDataLines(theStex1);
	if (theStex2) {
		*theCtrlFile << 'e' << endl;
		pointCount += dumpDataLines(theStex2);
	}

	return pointCount;
}

int LevelTraceFig::dumpDataLines(const LevelStex *stex) {
	int pointCount = 0;
	for (int i = 0; i < theTrace->count(); ++i)
		pointCount += dumpDataLine(stex, theTrace->winPos(i), theTrace->winStats(i));

	return pointCount;
}

int LevelTraceFig::dumpDataLine(const LevelStex *stex, Time stamp, const StatIntvlRec &r) {
	const LevelStat &stat = stex->level(r);
	if (stat.known()) {
		dumpTime(stamp);
		*theCtrlFile << ' ' << stat.level() << endl;
		return 1;
	}
	return 0;	
}
